as_factor: convert character vector into a factor with names "values"...

View source: R/RcppExports.R

as_factorR Documentation

convert character vector into a factor with names "values" and "levels"

Description

convert character vector into a factor with names "values" and "levels"

Usage

as_factor(vals)

Arguments

vals

vector of values to evaluate

Value

factor with names "values" and "levels"


sccore documentation built on April 6, 2026, 5:06 p.m.